@@ -11,9 +11,24 @@ use std::borrow::Borrow;
 use std::convert::TryFrom;
 use std::ops;
 
+use super::error::Error;
 use super::qa::Qa;
 use super::qr::Qr;
 
+/// Combine the provided `qa` ([`Qa`]) position with the `qr` ([`Qr`])
+/// direction and returns `Ok(Qa)` if the resulting position is
+/// inside the grid, `Error` if it's not.
+#[inline]
+pub fn qaqr_resolve<T, U, const W: u16, const H: u16>(qa: T, qr: U) -> Result<Qa<W, H>, Error>
+where
+    T: Borrow<Qa<W, H>>,
+    U: Borrow<Qr>,
+{
+    let qat = <(i32, i32)>::from(qa.borrow());
+    let qrt = <(i32, i32)>::from(qr.borrow());
+    Qa::<W, H>::try_from((qat.0 + qrt.0, qat.1 + qrt.1))
+}
+
 /// Combine the provided `qa` ([`Qa`]) position with the `qr` ([`Qr`])
 /// direction and returns `Some(Qa)` if the resulting position is
 /// inside the grid, `None` if it's not.
@@ -25,9 +40,7 @@ where
     T: Borrow<Qa<W, H>>,
     U: Borrow<Qr>,
 {
-    let qat = <(i32, i32)>::from(qa.borrow());
-    let qrt = <(i32, i32)>::from(qr.borrow());
-    Qa::<W, H>::try_from((qat.0 + qrt.0, qat.1 + qrt.1)).ok()
+    qaqr_resolve(qa, qr).ok()
 }
 
 impl<const W: u16, const H: u16> ops::Add<Qr> for Qa<W, H> {
