@@ -34,6 +34,16 @@ fn test_usize() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn test_tryfrom_qa() -> Result<()> {
+    assert_eq!(Qa::tryfrom_qa(Qa2::FIRST)?, Qa::try_from(0_usize)?);
+    assert_eq!(Qa::tryfrom_qa(Qa5::FIRST)?, Qa::try_from(0_usize)?);
+    assert_eq!(Qa::tryfrom_qa(Qa2::LAST)?, Qa::tryfrom_tuple((1, 1))?);
+    assert_eq!(Qa::tryfrom_qa(Qa5::LAST)?, Qa::tryfrom_tuple((4, 4))?);
+    assert!(Qa2::tryfrom_qa(Qa::LAST).is_err());
+    Ok(())
+}
+
 #[test]
 fn test_out_of_bounds() -> Result<()> {
     let q1result = Qa::try_from((6_u16, 3_u16));
@@ -121,6 +131,16 @@ fn test_manhattan() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn test_inside() -> Result<()> {
+    for qa in Qa::iter() {
+        assert!(qa.inside(Qa::TOP_LEFT, Qa::BOTTOM_RIGHT));
+        assert!(qa.inside(qa, qa));
+    }
+    assert!(!Qa::BOTTOM_RIGHT.inside(Qa::TOP_LEFT, Qa::CENTER));
+    Ok(())
+}
+
 #[test]
 fn test_flips() -> Result<()> {
     assert_eq!(Qa::TOP_LEFT.flip_v(), Qa::BOTTOM_LEFT);
