@@ -35,7 +35,13 @@ fn do_test_iter<const D: bool>() -> Result<()> {
     println!("{:?}", iter);
     let div = if D { 1 } else { 2 };
     for (i, qr) in iter.enumerate() {
-        println!("i {}, qr {}, from {}", i, qr, usize::from(qr));
+        println!(
+            "i {}, qr {}, from {}, from& {}",
+            i,
+            qr,
+            usize::from(qr),
+            usize::from(&qr)
+        );
         assert_eq!(usize::from(qr) / div, i);
         assert_eq!(qr, Qr::from(qr));
         println!("{}", qr);
@@ -82,6 +88,17 @@ fn test_iter() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn test_names() -> Result<()> {
+    let mut iter = Qr::iter::<true>();
+    assert_eq!(iter.next().map(|qr| qr.name_cardinal()), Some("N"));
+    assert_eq!(iter.next().map(|qr| qr.name_direction()), Some("UP-RIGHT"));
+    assert_eq!(iter.next().map(|qr| qr.name_direction()), Some("RIGHT"));
+    assert_eq!(iter.next().map(|qr| qr.name_cardinal()), Some("SE"));
+    assert_eq!(iter.next().map(|qr| qr.name_utf8()), Some("\u{2193}"));
+    Ok(())
+}
+
 #[test]
 fn test_is_diagonal() -> Result<()> {
     assert!(!Qr::N.is_diagonal());
@@ -94,3 +111,52 @@ fn test_is_diagonal() -> Result<()> {
     assert!(Qr::NW.is_diagonal());
     Ok(())
 }
+
+#[test]
+fn test_neg() -> Result<()> {
+    assert_eq!(-Qr::N, Qr::S);
+    assert_eq!(-Qr::NE, Qr::SW);
+    assert_eq!(-Qr::E, Qr::W);
+    assert_eq!(-Qr::SE, Qr::NW);
+    assert_eq!(-Qr::S, Qr::N);
+    assert_eq!(-Qr::SW, Qr::NE);
+    assert_eq!(-Qr::W, Qr::E);
+    assert_eq!(-Qr::NW, Qr::SE);
+    for qr in Qr::iter::<true>() {
+        assert_eq!(-(-&qr), qr);
+    }
+    Ok(())
+}
+
+#[test]
+fn test_add() -> Result<()> {
+    assert_eq!(Qr::S + Qr::N, Qr::S);
+    assert_eq!(Qr::S + Qr::NE, Qr::SW);
+    assert_eq!(Qr::S + Qr::E, Qr::W);
+    assert_eq!(Qr::S + Qr::SE, Qr::NW);
+    assert_eq!(Qr::S + Qr::S, Qr::N);
+    assert_eq!(Qr::S + Qr::SW, Qr::NE);
+    assert_eq!(Qr::S + Qr::W, Qr::E);
+    assert_eq!(Qr::S + Qr::NW, Qr::SE);
+    Ok(())
+}
+
+#[test]
+fn test_addassign() -> Result<()> {
+    let mut qr = Qr::N;
+    qr += Qr::NE;
+    assert_eq!(qr, Qr::NE);
+    qr += Qr::NE;
+    assert_eq!(qr, Qr::E);
+    qr += Qr::W;
+    assert_eq!(qr, Qr::N);
+    qr += Qr::NW;
+    assert_eq!(qr, Qr::NW);
+    qr += Qr::SE;
+    assert_eq!(qr, Qr::E);
+    qr += Qr::SE;
+    assert_eq!(qr, Qr::SW);
+    qr += Qr::SE;
+    assert_eq!(qr, Qr::N);
+    Ok(())
+}
